@@ -256,6 +256,17 @@ TEST_CASE("EarlyStopAtMinLossCustomLambdaTest", "[CallbacksTest]")
     REQUIRE(std::abs(coordinates[i]) >= 3.0);
 }
 
+/**
+ * Make sure we invoke all callbacks (ActiveCMAES).
+ */
+TEST_CASE("ActiveCMAESCallbacksFullFunctionTest", "[CallbacksTest]")
+{
+  BoundaryBoxConstraint<> b(-1, 1);
+  ActiveCMAES<FullSelection, BoundaryBoxConstraint<>> optimizer(0, b, 32, 3, 1e-3);
+  CallbacksFullFunctionTest(optimizer, true, false, false, false, true, true,
+    false, false, true);
+}
+
 /**
  * Make sure we invoke all callbacks (AdaBound).
  */
@@ -312,9 +323,10 @@ TEST_CASE("BigBatchSGDCallbacksFullFunctionTest", "[CallbacksTest]")
  */
 TEST_CASE("CMAESCallbacksFullFunctionTest", "[CallbacksTest]")
 {
-  CMAES<> optimizer(0, -1, 1, 32, 3, 1e-3);
+  BoundaryBoxConstraint<> b(-1, 1);
+  CMAES<FullSelection, BoundaryBoxConstraint<>> optimizer(0, b, 32, 3, 1e-3);
   CallbacksFullFunctionTest(optimizer, true, false, false, false, true, true,
-      false, false, true);
+    false, false, true);
 }
 
 /**
