@@ -28,8 +28,7 @@ TEST_CASE("FWOMPTest", "[FrankWolfeTest]")
   mat B1 = eye(3, 3);
   mat B2 = 0.1 * randn(3, k);
   mat A = join_horiz(B1, B2); // The dictionary is input as columns of A.
-  vec b;
-  b << 1 << 1 << 0; // Vector to be sparsely approximated.
+  vec b = {1.0, 1.0, 0.0}; // Vector to be sparsely approximated.
 
   FuncSq f(A, b);
   ConstrLpBallSolver linearConstrSolver(1);
@@ -85,14 +84,12 @@ TEST_CASE("FWPruneSupportOMP", "[FrankWolfeTest]")
 {
   // The dictionary is input as columns of A.
   const int k = 3;
-  mat B1;
-  B1 << 1 << 0 << 1 << endr
-     << 0 << 1 << 1 << endr
-     << 0 << 0 << 1 << endr;
+  mat B1 = { { 1.0, 0.0, 1.0 },
+             { 0.0, 1.0, 1.0 },
+             { 0.0, 0.0, 1.0 } };
   mat B2 = randu(k, k);
   mat A = join_horiz(B1, B2); // The dictionary is input as columns of A.
-  vec b;
-  b << 1 << 1 << 0; // Vector to be sparsely approximated.
+  vec b = { 1.0, 1.0, 0.0 }; // Vector to be sparsely approximated.
 
   FuncSq f(A, b);
   ConstrLpBallSolver linearConstrSolver(1);
@@ -115,8 +112,7 @@ TEST_CASE("FWAtomNormConstraint", "[FrankWolfeTest]")
   mat B1 = eye(3, 3);
   mat B2 = 0.1 * randn(3, k);
   mat A = join_horiz(B1, B2); // The dictionary is input as columns of A.
-  vec b;
-  b << 1 << 1 << 0; // Vector to be sparsely approximated.
+  vec b = { 1.0, 1.0, 0.0 }; // Vector to be sparsely approximated.
 
   FuncSq f(A, b);
   ConstrLpBallSolver linearConstrSolver(1);
