@@ -35,9 +35,6 @@ TEST_CASE("RMSPropLogisticRegressionFMatTest", "[rmsprop]")
   LogisticRegressionFunctionTest<arma::fmat>(optimizer, 0.003, 0.006);
 }
 
-#if ARMA_VERSION_MAJOR > 9 ||\
-    (ARMA_VERSION_MAJOR == 9 && ARMA_VERSION_MINOR >= 400)
-
 /**
  * Run RMSProp on logistic regression and make sure the results are acceptable.
  * Use arma::sp_mat.
@@ -47,5 +44,3 @@ TEST_CASE("RMSPropLogisticRegressionSpMatTest", "[rmsprop]")
   RMSProp optimizer;
   LogisticRegressionFunctionTest<arma::sp_mat>(optimizer, 0.003, 0.006);
 }
-
-#endif
